@@ -9,7 +9,6 @@
 #'   DESCRIPTION file is sought first in the local package library and then
 #'   on CRAN.
 #' * Fixed templates:
-#'   - Travis CI: `https://travis-ci.{EXT}/{OWNER}/{PACKAGE}`
 #'   - Circle CI: `https://circleci.com/gh/{OWNER}/{PACKAGE}`
 #'   - CRAN landing page: `https://cran.r-project.org/package={PACKAGE}`
 #'   - GitHub mirror of a CRAN package: `https://github.com/cran/{PACKAGE}`
@@ -29,8 +28,6 @@
 #'   issue.
 #' * `browse_github_pulls()`: Visits the GitHub Pull Request index or one
 #'   specific pull request.
-#' * `browse_travis()`: Visits the project's page on
-#'   [Travis CI](https://travis-ci.com).
 #' * `browse_circleci()`: Visits the project's page on
 #'   [Circle CI](https://circleci.com).
 #' * `browse_cran()`: Visits the package on CRAN, via the canonical URL.
@@ -50,7 +47,6 @@
 #' browse_github_issues("fs", 1)
 #' browse_github_pulls("curl")
 #' browse_github_pulls("curl", 183)
-#' browse_travis("gert", ext = "org")
 #' browse_cran("MASS")
 #' @name browse-this
 NULL
@@ -58,7 +54,8 @@ NULL
 #' @export
 #' @rdname browse-this
 browse_package <- function(package = NULL) {
-  stopifnot(is.null(package) || is_string(package))
+  maybe_name(package)
+
   if (is.null(package)) {
     check_is_project()
   }
@@ -76,8 +73,14 @@ browse_package <- function(package = NULL) {
     grl <- grl[ord, ]
     grl <- set_names(grl$url, nm = grl$remote)
     parsed <- parse_github_remotes(grl)
-    urls <- c(urls, glue_data(parsed, "https://{host}/{repo_owner}/{repo_name}"))
-    details <- c(details, map(parsed$name, ~ glue("{ui_value(.x)} remote")))
+    urls <- c(
+      urls,
+      glue_data(parsed, "https://{host}/{repo_owner}/{repo_name}")
+    )
+    details <- c(
+      details,
+      map(parsed$name, \(x) cli::cli_fmt(cli::cli_text("{.val {x}} remote")))
+    )
   }
 
   desc_urls_dat <- desc_urls(package, include_cran = TRUE)
@@ -86,11 +89,17 @@ browse_package <- function(package = NULL) {
     details,
     map(
       desc_urls_dat$desc_field,
-      ~ if (is.na(.x)) "CRAN" else glue("{ui_field(.x)} field in DESCRIPTION")
+      \(x) {
+        if (is.na(x)) {
+          "CRAN"
+        } else {
+          cli::cli_fmt(cli::cli_text("{.field {x}} field in DESCRIPTION"))
+        }
+      }
     )
   )
   if (length(urls) == 0) {
-    ui_oops("Can't find any URLs")
+    ui_bullets(c(x = "Can't find any URLs."))
     return(invisible(character()))
   }
 
@@ -100,8 +109,9 @@ browse_package <- function(package = NULL) {
 
   prompt <- "Which URL do you want to visit? (0 to exit)"
   pretty <- purrr::map2(
-    format(urls, justify = "left"), details,
-    ~ glue("{.x} ({.y})")
+    format(urls, justify = "left"),
+    details,
+    \(x, y) glue("{x} ({y})")
   )
   choice <- utils::menu(title = prompt, choices = pretty)
   if (choice == 0) {
@@ -138,16 +148,6 @@ browse_github_actions <- function(package = NULL) {
   view_url(github_url(package), "actions")
 }
 
-#' @export
-#' @rdname browse-this
-#' @param ext Version of travis to use.
-browse_travis <- function(package = NULL, ext = c("com", "org")) {
-  gh <- github_url(package)
-  ext <- arg_match(ext)
-  travis_url <- glue("travis-ci.{ext}")
-  view_url(sub("github.com", travis_url, gh))
-}
-
 #' @export
 #' @rdname browse-this
 browse_circleci <- function(package = NULL) {
@@ -167,7 +167,7 @@ browse_cran <- function(package = NULL) {
 # 2. BugReports/URL fields of DESCRIPTION (active project or arbitrary
 #    installed package)
 github_url <- function(package = NULL) {
-  stopifnot(is.null(package) || is_string(package))
+  maybe_name(package)
 
   if (is.null(package)) {
     check_is_project()
@@ -181,15 +181,17 @@ github_url <- function(package = NULL) {
 
   if (is.null(desc_urls_dat)) {
     if (is.null(package)) {
-      ui_stop("
-        Project {ui_value(project_name())} has no DESCRIPTION file and \\
-        has no GitHub remotes configured
-        No way to discover URLs")
+      ui_abort(c(
+        "Project {.val {project_name()}} has no DESCRIPTION file and
+         has no GitHub remotes configured.",
+        "No way to discover URLs."
+      ))
     } else {
-      ui_stop("
-        Can't find DESCRIPTION for package {ui_value(package)} locally \\
-        or on CRAN
-        No way to discover URLs")
+      ui_abort(c(
+        "Can't find DESCRIPTION for package {.pkg {package}} locally
+         or on CRAN.",
+        "No way to discover URLs."
+      ))
     }
   }
 
@@ -201,13 +203,16 @@ github_url <- function(package = NULL) {
   }
 
   if (is.null(package)) {
-    ui_stop("
-      Project {ui_value(project_name())} has no GitHub remotes configured \\
-      and has no GitHub URLs in DESCRIPTION")
+    ui_abort(
+      "
+      Project {.val {project_name()}} has no GitHub remotes configured
+      and has no GitHub URLs in DESCRIPTION."
+    )
   }
-  ui_warn("
-    Package {ui_value(package)} has no GitHub URLs in DESCRIPTION
-    Trying the GitHub CRAN mirror")
+  cli::cli_warn(c(
+    "!" = "Package {.val {package}} has no GitHub URLs in DESCRIPTION.",
+    " " = "Trying the GitHub CRAN mirror."
+  ))
   glue_chr("https://github.com/cran/{package}")
 }
 
