@@ -28,20 +28,24 @@ use_testthat <- function(edition = NULL, parallel = FALSE) {
 }
 
 use_testthat_impl <- function(edition = NULL, parallel = FALSE) {
-  check_installed("testthat")
-  if (utils::packageVersion("testthat") < "2.1.0") {
-    ui_abort("
-      {.pkg testthat} 2.1.0 or greater needed. Please install before re-trying")
-  }
+  check_installed("testthat", version = "2.1.0")
 
   if (is_package()) {
     edition <- check_edition(edition)
 
     use_dependency("testthat", "Suggests", paste0(edition, ".0.0"))
-    proj_desc_field_update("Config/testthat/edition", as.character(edition), overwrite = TRUE)
+    proj_desc_field_update(
+      "Config/testthat/edition",
+      as.character(edition),
+      overwrite = TRUE
+    )
 
     if (parallel) {
-      proj_desc_field_update("Config/testthat/parallel", "true", overwrite = TRUE)
+      proj_desc_field_update(
+        "Config/testthat/parallel",
+        "true",
+        overwrite = TRUE
+      )
     } else {
       proj_desc()$del("Config/testthat/parallel")
     }
@@ -60,7 +64,7 @@ use_testthat_impl <- function(edition = NULL, parallel = FALSE) {
 }
 
 check_edition <- function(edition = NULL) {
-  version <- utils::packageVersion("testthat")[[1, c(1, 2)]]
+  version <- testthat_version()[[1, c(1, 2)]]
   if (version[[2]] == "99") {
     version <- version[[1]] + 1L
   } else {
@@ -74,15 +78,21 @@ check_edition <- function(edition = NULL) {
       ui_abort("{.arg edition} must be a single number.")
     }
     if (edition > version) {
-      vers <- utils::packageVersion("testthat")
-      ui_abort("
+      vers <- testthat_version()
+      ui_abort(
+        "
         {.var edition} ({edition}) not available in installed verion of
-        {.pkg testthat} ({vers}).")
+        {.pkg testthat} ({vers})."
+      )
     }
     as.integer(edition)
   }
 }
 
+# wrapping so we can mock this in tests
+testthat_version <- function() {
+  utils::packageVersion("testthat")
+}
 
 uses_testthat <- function() {
   paths <- proj_path(c(path("inst", "tests"), path("tests", "testthat")))
