@@ -16,13 +16,13 @@
 #' @export
 #' @examples
 #' \dontrun{
-#' use_upkeep_issue(2023)
+#' use_upkeep_issue()
 #' }
 use_upkeep_issue <- function(year = NULL) {
   make_upkeep_issue(year = year, tidy = FALSE)
 }
 
-make_upkeep_issue <- function(year, tidy) {
+make_upkeep_issue <- function(year, last_upkeep, tidy) {
   who <- if (tidy) "use_tidy_upkeep_issue()" else "use_upkeep_issue()"
   check_is_package(who)
 
@@ -41,7 +41,7 @@ make_upkeep_issue <- function(year, tidy) {
 
   gh <- gh_tr(tr)
   if (tidy) {
-    checklist <- tidy_upkeep_checklist(year, repo_spec = tr$repo_spec)
+    checklist <- tidy_upkeep_checklist(last_upkeep, repo_spec = tr$repo_spec)
   } else {
     checklist <- upkeep_checklist(tr)
   }
@@ -66,6 +66,12 @@ upkeep_checklist <- function(target_repo = NULL) {
     todo("`usethis::use_roxygen_md()`", !is_true(uses_roxygen_md())),
     todo("`usethis::use_github_links()`", !has_github_links),
     todo("`usethis::use_pkgdown_github_pages()`", !uses_pkgdown()),
+    todo(
+      "
+      Consider using Bootstrap 5 in your pkgdown site. \\
+      Read more in the [pkgdown customisation article](https://pkgdown.r-lib.org/articles/customise.html).",
+      uses_pkgdown() && !uses_pkgdown_bootstrap_version(5)
+    ),
     todo("`usethis::use_tidy_description()`"),
     todo(
       "
@@ -86,10 +92,12 @@ upkeep_checklist <- function(target_repo = NULL) {
       [testthat 3e vignette](https://testthat.r-lib.org/articles/third-edition.html)",
       uses_old_testthat_edition(current = 3)
     ),
-    todo("
+    todo(
+      "
       Align the names of `R/` files and `test/` files for workflow happiness. \\
       The docs for `usethis::use_r()` include a helpful script. \\
-      `usethis::rename_files()` may be be useful."),
+      `usethis::rename_files()` may be be useful."
+    ),
     todo(
       "Consider changing default branch from `master` to `main`",
       git_default_branch() == "master"
@@ -100,15 +108,17 @@ upkeep_checklist <- function(target_repo = NULL) {
       See `usethis::use_cran_comments()`.",
       has_old_cran_comments()
     ),
-    todo("
+    todo(
+      "
       Add alt-text to pictures, plots, etc; see \\
-      <https://posit.co/blog/knitr-fig-alt/> for examples"),
-      "",
-      "Set up or update GitHub Actions. \\
+      <https://posit.co/blog/knitr-fig-alt/> for examples"
+    ),
+    "",
+    "Set up or update GitHub Actions. \\
       Updating workflows to the latest version will often fix troublesome actions:",
-      todo("`usethis::use_github_action('check-standard')`"),
-      todo("`usethis::use_github_action('pkgdown')`", uses_pkgdown()),
-      todo("`usethis::use_github_action('test-coverage')`", uses_testthat())
+    todo("`usethis::use_github_action('check-standard')`"),
+    todo("`usethis::use_github_action('pkgdown')`", uses_pkgdown()),
+    todo("`usethis::use_github_action('test-coverage')`", uses_testthat())
   )
 
   c(bullets, upkeep_extra_bullets(), checklist_footer(tidy = FALSE))
@@ -118,30 +128,35 @@ upkeep_checklist <- function(target_repo = NULL) {
 
 #' @export
 #' @rdname tidyverse
-#' @param year Approximate year when you last touched this package. If `NULL`,
-#'   the default, will give you a full set of actions to perform.
-use_tidy_upkeep_issue <- function(year = NULL) {
-  make_upkeep_issue(year = year, tidy = TRUE)
+#' @param last_upkeep Year of last upkeep. By default, the
+#' `Config/usethis/last-upkeep` field in `DESCRIPTION` is consulted for this, if
+#' it's defined. If there's no information on the last upkeep, the issue will
+#' contain the full checklist.
+use_tidy_upkeep_issue <- function(last_upkeep = last_upkeep_year()) {
+  make_upkeep_issue(year = NULL, last_upkeep = last_upkeep, tidy = TRUE)
+  record_upkeep_date(Sys.Date())
 }
 
 # for mocking
 Sys.Date <- NULL
 
-tidy_upkeep_checklist <- function(year = NULL, repo_spec = "OWNER/REPO") {
+tidy_upkeep_checklist <- function(
+  last_upkeep = last_upkeep_year(),
+  repo_spec = "OWNER/REPO"
+) {
+  desc <- proj_desc()
 
   posit_pkg <- is_posit_pkg()
   posit_person_ok <- is_posit_person_canonical()
 
-  year <- year %||% 2000
-
   bullets <- c(
     "### To begin",
     "",
-    todo('`pr_init("upkeep-{format(Sys.Date(), "%Y-%m")}")`'),
+    todo('`usethis::pr_init("upkeep-{format(Sys.Date(), "%Y-%m")}")`'),
     ""
   )
 
-  if (year <= 2000) {
+  if (last_upkeep <= 2000) {
     bullets <- c(
       bullets,
       "### Pre-history",
@@ -156,7 +171,7 @@ tidy_upkeep_checklist <- function(year = NULL, repo_spec = "OWNER/REPO") {
       ""
     )
   }
-  if (year <= 2020) {
+  if (last_upkeep <= 2020) {
     bullets <- c(
       bullets,
       "### 2020",
@@ -167,7 +182,7 @@ tidy_upkeep_checklist <- function(year = NULL, repo_spec = "OWNER/REPO") {
       ""
     )
   }
-  if (year <= 2021) {
+  if (last_upkeep <= 2021) {
     bullets <- c(
       bullets,
       "### 2021",
@@ -177,22 +192,24 @@ tidy_upkeep_checklist <- function(year = NULL, repo_spec = "OWNER/REPO") {
       ""
     )
   }
-  if (year <= 2022) {
+  if (last_upkeep <= 2022) {
     bullets <- c(
       bullets,
       "### 2022",
       "",
       todo("Handle and close any still-open `master` --> `main` issues"),
       todo('`usethis:::use_codecov_badge("{repo_spec}")`'),
-      todo("Update pkgdown site using instructions at <https://tidytemplate.tidyverse.org>"),
-      todo("Update lifecycle badges with more accessible SVGs: `usethis::use_lifecycle()`"),
+      todo(
+        "Update pkgdown site using instructions at <https://tidytemplate.tidyverse.org>"
+      ),
+      todo(
+        "Update lifecycle badges with more accessible SVGs: `usethis::use_lifecycle()`"
+      ),
       ""
     )
   }
 
-  if (year <= 2023) {
-    desc <- proj_desc()
-
+  if (last_upkeep <= 2023) {
     bullets <- c(
       bullets,
       "### 2023",
@@ -214,27 +231,36 @@ tidy_upkeep_checklist <- function(year = NULL, repo_spec = "OWNER/REPO") {
         with DESCRIPTION changes",
         author_has_rstudio_email() || (posit_pkg && !posit_person_ok)
       ),
-      todo("`usethis::use_tidy_logo(); pkgdown::build_favicons(overwrite = TRUE)`"),
+      todo(
+        "`usethis::use_tidy_logo(); pkgdown::build_favicons(overwrite = TRUE)`"
+      ),
       todo("`usethis::use_tidy_coc()`"),
       todo(
         "Modernize citation files; see updated `use_citation()`",
         has_citation_file()
       ),
       todo('Use `pak::pak("{repo_spec}")` in README'),
-      todo("
+      todo(
+        "
         Consider running `usethis::use_tidy_dependencies()` and/or \\
-        replace compat files with `use_standalone()`"),
-      todo("Use cli errors or [file an issue](new) if you don\'t have time to do it now"),
-      todo('
+        replace compat files with `use_standalone()`"
+      ),
+      todo(
+        "Use cli errors or [file an issue](new) if you don\'t have time to do it now"
+      ),
+      todo(
+        '
         `usethis::use_standalone("r-lib/rlang", "types-check")` \\
         instead of home grown argument checkers;
-        or [file an issue](new) if you don\'t have time to do it now'),
+        or [file an issue](new) if you don\'t have time to do it now'
+      ),
       todo(
         "
         Change files ending in `.r` to `.R` in `R/` and/or `tests/testthat/`",
         lowercase_r()
       ),
-      todo("
+      todo(
+        "
         Add alt-text to pictures, plots, etc; see \\
         https://posit.co/blog/knitr-fig-alt/ for examples"
       ),
@@ -242,19 +268,61 @@ tidy_upkeep_checklist <- function(year = NULL, repo_spec = "OWNER/REPO") {
     )
   }
 
+  if (last_upkeep <= 2025) {
+    bullets <- c(
+      bullets,
+      "### 2025",
+      "",
+      todo("`usethis::use_air()` <https://posit-dev.github.io/air/>"),
+      todo('`usethis::use_package("R", "Depends", "4.1")`'),
+      todo("Switch to the base pipe (`|>`)"),
+      todo("Switch to the base anonymous function syntax (`\\(x)`) "),
+      todo(
+        '
+        Add ROR for Posit in `DESCRIPTION`:
+        `person("Posit Software, PBC", role = c("cph", "fnd"), comment = c(ROR = "03wc8by49"))`',
+        posit_pkg && !posit_person_ok
+      ),
+      todo(
+        '
+        Convert in-header chunk options to the newer in-body style used by Quarto:
+        `fs::dir_ls("vignettes", regexp = "[.][Rq]md$") |> purrr::walk(\\(x) knitr::convert_chunk_header(x, output = identity, type = "yaml"))`
+        '
+      ),
+      todo(
+        "Switch to `expect_snapshot(error = TRUE)` instead of calling `expect_error()` without specifying `class =`"
+      ),
+      ""
+    )
+  }
+
+  minimum_r_version <- pkg_minimum_r_version()
   bullets <- c(
     bullets,
     "### To finish",
     "",
-    todo("`usethis::use_mit_license()`", grepl("MIT", desc$get_field("License"))),
+    # TODO: if the most recent year doesn't nudge about the minimum R version,
+    # re-introduce that todo()
+    #
+    # todo(
+    #   '`usethis::use_package("R", "Depends", "{tidy_minimum_r_version()}")`',
+    #   is.na(minimum_r_version) || tidy_minimum_r_version() > minimum_r_version
+    # ),
     todo(
-      '`usethis::use_package("R", "Depends", "{tidy_minimum_r_version()}")`',
-      tidy_minimum_r_version() > pkg_minimum_r_version()
+      "`usethis::use_mit_license()`",
+      grepl("MIT", desc$get_field("License"))
     ),
     todo("`usethis::use_tidy_description()`"),
     todo("`usethis::use_tidy_github_actions()`"),
     todo("`devtools::build_readme()`"),
-    todo("[Re-publish released site](https://pkgdown.r-lib.org/dev/articles/how-to-update-released-site.html) if needed"),
+    todo(
+      "
+      Add alt-text to pictures, plots, etc; see \\
+      https://posit.co/blog/knitr-fig-alt/ for examples"
+    ),
+    todo(
+      "[Re-publish released site](https://pkgdown.r-lib.org/dev/articles/how-to-update-released-site.html) if needed"
+    ),
     ""
   )
 
@@ -312,10 +380,12 @@ upkeep_extra_bullets <- function(env = NULL) {
 
 checklist_footer <- function(tidy) {
   tidy_fun <- if (tidy) "tidy_" else ""
-  glue('<sup>\\
+  glue(
+    '<sup>\\
     Created on {Sys.Date()} with `usethis::use_{tidy_fun}upkeep_issue()`, using \\
     [usethis v{usethis_version()}](https://usethis.r-lib.org)\\
-    </sup>')
+    </sup>'
+  )
 }
 
 usethis_version <- function() {
@@ -327,3 +397,18 @@ has_old_cran_comments <- function() {
   file_exists(cc) &&
     any(grepl("# test environment", readLines(cc), ignore.case = TRUE))
 }
+
+last_upkeep_date <- function() {
+  as.Date(
+    proj_desc()$get_field("Config/usethis/last-upkeep", "2000-01-01"),
+    format = "%Y-%m-%d"
+  )
+}
+
+last_upkeep_year <- function() {
+  as.integer(format(last_upkeep_date(), "%Y"))
+}
+
+record_upkeep_date <- function(date) {
+  proj_desc_field_update("Config/usethis/last-upkeep", format(date, "%Y-%m-%d"))
+}
