@@ -42,15 +42,16 @@
 #'   save_as = ".github/workflows/R-CMD-check.yaml"
 #' )
 #' }
-use_github_file <- function(repo_spec,
-                            path = NULL,
-                            save_as = NULL,
-                            ref = NULL,
-                            ignore = FALSE,
-                            open = FALSE,
-                            overwrite = FALSE,
-                            host = NULL) {
-
+use_github_file <- function(
+  repo_spec,
+  path = NULL,
+  save_as = NULL,
+  ref = NULL,
+  ignore = FALSE,
+  open = FALSE,
+  overwrite = FALSE,
+  host = NULL
+) {
   check_name(repo_spec)
   maybe_name(path)
   maybe_name(save_as)
@@ -63,16 +64,18 @@ use_github_file <- function(repo_spec,
   dat <- parse_file_url(repo_spec)
   if (dat$parsed) {
     repo_spec <- dat$repo_spec
-    path      <- dat$path
-    ref       <- dat$ref
-    host      <- dat$host
+    path <- dat$path
+    ref <- dat$ref
+    host <- dat$host
   }
 
   save_as <- save_as %||% path_file(path)
 
   ref_string <- if (is.null(ref)) "" else glue("@{ref}")
   github_string <- glue("{repo_spec}/{path}{ref_string}")
-  ui_done("Saving {ui_path(github_string)} to {ui_path(save_as)}")
+  ui_bullets(c(
+    "v" = "Saving {.val {github_string}} to {.path {pth(save_as)}}."
+  ))
 
   lines <- read_github_file(
     repo_spec = repo_spec,
@@ -137,13 +140,15 @@ parse_file_url <- function(x) {
 
   # TODO: generalize here for GHE hosts that don't include 'github'
   if (!grepl("github", dat$host)) {
-    ui_stop("URL doesn't seem to be associated with GitHub.")
+    ui_abort("URL doesn't seem to be associated with GitHub.")
   }
 
-  if (!grepl("^(raw[.])?github", dat$host) ||
+  if (
+    !grepl("^(raw[.])?github", dat$host) ||
       !nzchar(dat$fragment) ||
-      (grepl("^github", dat$host) && !grepl("^/blob/", dat$fragment))) {
-    ui_stop("Can't parse the URL provided via {ui_code('repo_spec')}.")
+      (grepl("^github", dat$host) && !grepl("^/blob/", dat$fragment))
+  ) {
+    ui_abort("Can't parse the URL provided via {.arg repo_spec}.")
   }
   out$parsed <- TRUE
 
