@@ -7,17 +7,16 @@ test_that("use_cpp11() requires a package", {
 test_that("use_cpp11() creates files/dirs, edits DESCRIPTION and .gitignore", {
   create_local_package()
   use_roxygen_md()
+  use_package_doc() # needed for use_cpp11()
 
   local_interactive(FALSE)
   local_check_installed()
   local_mocked_bindings(check_cpp_register_deps = function() invisible())
 
   use_cpp11()
-
-  deps <- proj_deps()
-  expect_equal(deps$type, "LinkingTo")
-  expect_equal(deps$package, "cpp11")
+  expect_match(desc::desc_get("LinkingTo"), "cpp11")
   expect_proj_dir("src")
+  expect_proj_file("src", "code.cpp")
 
   ignores <- read_utf8(proj_path("src", ".gitignore"))
   expect_contains(ignores, c("*.o", "*.so", "*.dll"))
